[packages/rpm-build-tools] do not purge if stash list not empty

glen glen at pld-linux.org
Sat Mar 9 14:33:58 CET 2013


commit 2bfd8fccae84b3ac78090934d3ba1b4e9d6cf850
Author: Elan Ruusamäe <glen at delfi.ee>
Date:   Sat Mar 9 15:32:53 2013 +0200

    do not purge if stash list not empty

 purge-packages.sh | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
---
diff --git a/purge-packages.sh b/purge-packages.sh
index dd08128..520ae3b 100755
--- a/purge-packages.sh
+++ b/purge-packages.sh
@@ -18,11 +18,12 @@ for pkg in */.git; do
 	pkg=${pkg%/.git}
 	cd "$pkg"
 	status=$(git status --porcelain)
+	stash=$(git stash list)
 
 	# FIXME: does not currently handle if some pushes are not made!
-	if [ -n "$status" ]; then
+	if [ -n "$status" ] || [ -n "$stash" ]; then
 		cat <<-EOF
 		* Package $pkg - Untracked files. Invoke gc
 
 		$status
 		EOF
================================================================

---- gitweb:
@@ -18,11 +18,12 @@ for pkg in */.git; do
 		cat <<-EOF
-		* Package $pkg - Untracked files. Invoke gc
+		* Package $pkg - Untracked files or stash not empty. Invoke gc
 
 		$status

http://git.pld-linux.org/gitweb.cgi/packages/rpm-build-tools.git/commitdiff/a23747f7a26297be818afc314142eadb53c992dc



More information about the pld-cvs-commit mailing list